import 'dart:convert';

import 'package:flutter/material.dart';

import '../../../models/counts_by_day.dart';
import '../../../network/scrobbles_api.dart';
import '../../../ui/widgets/error.dart';
import '../../../ui/widgets/main_screen/counts_by_day_content.dart';

class ChartCountsByDayCard extends StatelessWidget {
  const ChartCountsByDayCard({super.key});

  @override
  Widget build(BuildContext context) {
    final int daysCount = 21;
    late Future<CountsByDayData> futureCountsByDay = ScrobblesApi.fetchCountsByDay(daysCount);

    return FutureBuilder<CountsByDayData>(
      future: futureCountsByDay,
      builder: (context, snapshot) {
        if (snapshot.hasError) {
          return ShowErrorWidget(message: '${snapshot.error}');
        }

        return Card(
          elevation: 2,
          shadowColor: Theme.of(context).colorScheme.shadow,
          color: Theme.of(context).colorScheme.surface,
          shape: const RoundedRectangleBorder(
            borderRadius: BorderRadius.all(
              Radius.circular(8),
            ),
          ),
          child: Padding(
            padding: const EdgeInsets.all(8.0),
            child: ChartCountsByDayCardContent(
              daysCount: daysCount,
              chartData: snapshot.hasData
                  ? CountsByDayData.fromJson(jsonDecode(snapshot.data.toString()))
                  : CountsByDayData.createEmpty(),
              isLoading: !snapshot.hasData,
            ),
          ),
        );
      },
    );
  }
}
